@@ -1,6 +1,6 @@
 /* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
- *  Copyright (C) 2009  Kouhei Sutou <kou@cozmixng.org>
+ *  Copyright (C) 2009-2012  Kouhei Sutou <kou@clear-code.com>
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -97,10 +97,12 @@ struct _CutCrashBacktrace
     struct sigaction previous_abort_action;
     struct sigaction previous_terminate_action;
     struct sigaction previous_interrupt_action;
+    struct sigaction previous_bus_error_action;
     gboolean set_segv_action;
     gboolean set_abort_action;
     gboolean set_terminate_action;
     gboolean set_interrupt_action;
+    gboolean set_bus_error_action;
 };
 
 static void
@@ -195,6 +197,7 @@ cut_crash_backtrace_new (jmp_buf *jump_buffer)
     struct sigaction *previous_abort_action;
     struct sigaction *previous_terminate_action;
     struct sigaction *previous_interrupt_action;
+    struct sigaction *previous_bus_error_action;
 
     crash_backtrace = g_new0(CutCrashBacktrace, 1);
     crash_backtrace->jump_buffer = jump_buffer;
@@ -202,12 +205,14 @@ cut_crash_backtrace_new (jmp_buf *jump_buffer)
     crash_backtrace->set_abort_action = TRUE;
     crash_backtrace->set_terminate_action = TRUE;
     crash_backtrace->set_interrupt_action = TRUE;
+    crash_backtrace->set_bus_error_action = TRUE;
 
     i_will_be_back_action = &(crash_backtrace->i_will_be_back_action);
     previous_segv_action = &(crash_backtrace->previous_segv_action);
     previous_abort_action = &(crash_backtrace->previous_abort_action);
     previous_terminate_action = &(crash_backtrace->previous_terminate_action);
     previous_interrupt_action = &(crash_backtrace->previous_interrupt_action);
+    previous_bus_error_action = &(crash_backtrace->previous_bus_error_action);
 
     i_will_be_back_action->sa_handler = i_will_be_back_handler;
     sigemptyset(&(i_will_be_back_action->sa_mask));
@@ -222,6 +227,9 @@ cut_crash_backtrace_new (jmp_buf *jump_buffer)
     if (sigaction(SIGINT, i_will_be_back_action,
                   previous_interrupt_action) == -1)
         crash_backtrace->set_interrupt_action = FALSE;
+    if (sigaction(SIGBUS, i_will_be_back_action,
+                  previous_bus_error_action) == -1)
+        crash_backtrace->set_bus_error_action = FALSE;
 
     crash_backtrace->previous = current_crash_backtrace;
     current_crash_backtrace = crash_backtrace;
@@ -240,6 +248,8 @@ cut_crash_backtrace_free (CutCrashBacktrace *crash_backtrace)
         sigaction(SIGABRT, &(crash_backtrace->previous_abort_action), NULL);
     if (crash_backtrace->set_segv_action)
         sigaction(SIGSEGV, &(crash_backtrace->previous_segv_action), NULL);
+    if (crash_backtrace->set_bus_error_action)
+        sigaction(SIGBUS, &(crash_backtrace->previous_bus_error_action), NULL);
 
     current_crash_backtrace = crash_backtrace->previous;
 
