@@ -1,6 +1,7 @@
 /* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
  *  Copyright (C) 2008  g新部 Hiroyuki Ikezoe  <poincare@ikezoe.net>
+ *  Copyright (C) 2009-2014  Kouhei Sutou  <kou@clear-code.com>
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -18,14 +19,13 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#  include <config.h>
 #endif /* HAVE_CONFIG_H */
 
 #include <glib.h>
 
 #include "cut-report.h"
 #include "cut-module.h"
-#include "cut-listener-utils.h"
 
 #define CUT_REPORT_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), CUT_TYPE_REPORT, CutReportPrivate))
 
@@ -52,7 +52,7 @@ static void get_property   (GObject         *object,
                             GParamSpec      *pspec);
 
 G_DEFINE_ABSTRACT_TYPE (CutReport, cut_report, G_TYPE_OBJECT)
-CUT_DEFINE_LISTENER_MODULE(report, REPORT)
+CUT_MODULE_DEFINE_INTERNAL_DEFINITIONS(report, REPORT)
 
 static void
 cut_report_class_init (CutReportClass *klass)
@@ -244,6 +244,34 @@ cut_report_get_notification_results (CutReport *report)
         return NULL;
 }
 
+gchar *
+cut_report_get_omission_results (CutReport *report)
+{
+    CutReportClass *klass;
+
+    g_return_val_if_fail(CUT_IS_REPORT(report), NULL);
+
+    klass = CUT_REPORT_GET_CLASS(report);
+    if (klass->get_omission_results)
+        return klass->get_omission_results(report);
+    else
+        return NULL;
+}
+
+gchar *
+cut_report_get_crash_results (CutReport *report)
+{
+    CutReportClass *klass;
+
+    g_return_val_if_fail(CUT_IS_REPORT(report), NULL);
+
+    klass = CUT_REPORT_GET_CLASS(report);
+    if (klass->get_crash_results)
+        return klass->get_crash_results(report);
+    else
+        return NULL;
+}
+
 gchar *
 cut_report_get_test_result(CutReport *report, const gchar *test_name)
 {
