@@ -1,6 +1,6 @@
 /* -*- Mode: C; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
- *  Copyright (C) 2007  Kouhei Sutou <kou@cozmixng.org>
+ *  Copyright (C) 2007-2009  Kouhei Sutou <kou@cozmixng.org>
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -18,7 +18,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#  include <config.h>
 #endif /* HAVE_CONFIG_H */
 
 #include <stdio.h>
@@ -40,9 +40,11 @@
 #include "cut-run-context.h"
 #include "cut-main.h"
 #include "cut-utils.h"
-#include "cut-marshalers.h"
 #include "cut-test-result.h"
+#include "cut-backtrace-entry.h"
+#include "cut-crash-backtrace.h"
 
+#include "../gcutter/gcut-marshalers.h"
 #include "../gcutter/gcut-error.h"
 
 #define CUT_TEST_SUITE_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), CUT_TYPE_TEST_SUITE, CutTestSuitePrivate))
@@ -69,11 +71,6 @@ enum
     LAST_SIGNAL
 };
 
-static jmp_buf jump_buffer;
-#ifndef G_OS_WIN32
-static gchar *backtrace = NULL;
-#endif
-
 static gint cut_test_suite_signals[LAST_SIGNAL] = {0};
 
 G_DEFINE_TYPE (CutTestSuite, cut_test_suite, CUT_TYPE_TEST_CONTAINER)
@@ -118,7 +115,7 @@ cut_test_suite_class_init (CutTestSuiteClass *klass)
                        G_SIGNAL_RUN_LAST,
                        G_STRUCT_OFFSET(CutTestSuiteClass, ready),
                        NULL, NULL,
-                       _cut_marshal_VOID__UINT_UINT,
+                       _gcut_marshal_VOID__UINT_UINT,
                        G_TYPE_NONE, 2, G_TYPE_UINT, G_TYPE_UINT);
 
     cut_test_suite_signals[START_TEST_CASE]
@@ -136,7 +133,7 @@ cut_test_suite_class_init (CutTestSuiteClass *klass)
                        G_SIGNAL_RUN_LAST,
                        G_STRUCT_OFFSET(CutTestSuiteClass, complete_test_case),
                        NULL, NULL,
-                       _cut_marshal_VOID__OBJECT_BOOLEAN,
+                       _gcut_marshal_VOID__OBJECT_BOOLEAN,
                        G_TYPE_NONE, 2, CUT_TYPE_TEST_CASE, G_TYPE_BOOLEAN);
 
     g_type_class_add_private(gobject_class, sizeof(CutTestSuitePrivate));
@@ -290,73 +287,6 @@ run_with_thread_support (CutTestSuite *test_suite, CutTestCase *test_case,
         run(info, success);
 }
 
-#ifndef G_OS_WIN32
-static void
-read_backtrace (int in_fd)
-{
-    GRegex *regex;
-    GString *buffer;
-    gchar window[4096];
-    gssize size;
-
-    buffer = g_string_new("");
-    while ((size = read(in_fd, window, sizeof(window))) > 0) {
-        g_string_append_len(buffer, window, size);
-    }
-
-    regex = g_regex_new("^.+?<signal handler called>\n",
-                        G_REGEX_MULTILINE | G_REGEX_DOTALL,
-                        G_REGEX_MATCH_NEWLINE_ANY, NULL);
-    if (regex) {
-        backtrace = g_regex_replace(regex, buffer->str, buffer->len, 0,
-                                    "", 0, NULL);
-        g_regex_unref(regex);
-        g_string_free(buffer, TRUE);
-    } else {
-        backtrace = g_string_free(buffer, FALSE);
-    }
-}
-
-static void
-collect_backtrace (void)
-{
-    int fds[2];
-    FILE *original_stdout, *pseudo_stdout;
-
-    if (pipe(fds) == -1) {
-        perror("unable to open pipe for collecting stack trace");
-        return;
-    }
-
-    original_stdout = stdout;
-    pseudo_stdout = fdopen(fds[1], "w");
-    if (!pseudo_stdout) {
-        perror("unable to open FILE for pipe");
-        close(fds[0]);
-        close(fds[1]);
-        return;
-    }
-    stdout = pseudo_stdout;
-    g_on_error_stack_trace(cut_get_cutter_command_path());
-    stdout = original_stdout;
-    fclose(pseudo_stdout);
-
-    read_backtrace(fds[0]);
-
-    close(fds[0]);
-    close(fds[1]);
-}
-
-static void
-i_will_be_back_handler (int signum)
-{
-    g_free(backtrace);
-    backtrace = NULL;
-    collect_backtrace();
-    longjmp(jump_buffer, signum);
-}
-#endif
-
 static void
 emit_ready_signal (CutTestSuite *test_suite, GList *test_cases,
                    CutRunContext *run_context)
@@ -390,14 +320,8 @@ cut_test_suite_run_test_cases (CutTestSuite *test_suite,
     gboolean try_thread;
     gboolean all_success = TRUE;
     gint signum;
-#ifndef G_OS_WIN32
-    struct sigaction i_will_be_back_action;
-    struct sigaction previous_segv_action, previous_abort_action;
-    struct sigaction previous_int_action;
-    gboolean set_segv_action = TRUE;
-    gboolean set_abort_action = TRUE;
-    gboolean set_int_action = TRUE;
-#endif
+    jmp_buf jump_buffer;
+    CutCrashBacktrace *crash_backtrace = NULL;
 
     priv = CUT_TEST_SUITE_GET_PRIVATE(test_suite);
 
@@ -405,18 +329,6 @@ cut_test_suite_run_test_cases (CutTestSuite *test_suite,
     sorted_test_cases = cut_run_context_sort_test_cases(run_context,
                                                         sorted_test_cases);
 
-#ifndef G_OS_WIN32
-    i_will_be_back_action.sa_handler = i_will_be_back_handler;
-    sigemptyset(&i_will_be_back_action.sa_mask);
-    i_will_be_back_action.sa_flags = 0;
-    if (sigaction(SIGSEGV, &i_will_be_back_action, &previous_segv_action) == -1)
-        set_segv_action = FALSE;
-    if (sigaction(SIGABRT, &i_will_be_back_action, &previous_abort_action) == -1)
-        set_abort_action = FALSE;
-    if (sigaction(SIGINT, &i_will_be_back_action, &previous_int_action) == -1)
-        set_int_action = FALSE;
-#endif
-
     try_thread = cut_run_context_get_multi_thread(run_context);
     if (try_thread) {
         GError *error = NULL;
@@ -430,9 +342,14 @@ cut_test_suite_run_test_cases (CutTestSuite *test_suite,
         }
     }
 
-    signum = setjmp(jump_buffer);
+    if (cut_run_context_get_handle_signals(run_context)) {
+        crash_backtrace = cut_crash_backtrace_new(&jump_buffer);
+        signum = setjmp(jump_buffer);
+    } else {
+        signum = 0;
+    }
     switch (signum) {
-      case 0:
+    case 0:
         emit_ready_signal(test_suite, sorted_test_cases, run_context);
         g_signal_emit_by_name(test_suite, "start", NULL);
 
@@ -463,26 +380,24 @@ cut_test_suite_run_test_cases (CutTestSuite *test_suite,
             cut_test_emit_result_signal(CUT_TEST(test_suite), NULL, result);
             g_object_unref(result);
         }
+        if (crash_backtrace)
+            cut_crash_backtrace_free(crash_backtrace);
         break;
 #ifndef G_OS_WIN32
-      case SIGSEGV:
-      case SIGABRT:
+    case SIGSEGV:
+    case SIGABRT:
+    case SIGTERM:
+    case SIGBUS:
         all_success = FALSE;
-        g_signal_emit_by_name(CUT_TEST(test_suite), "crashed", backtrace);
-        g_free(backtrace);
+        cut_crash_backtrace_emit(test_suite, NULL, NULL, NULL, NULL, NULL);
+        break;
+    case SIGINT:
+        cut_run_context_cancel(run_context);
         break;
 #endif
-      default:
+    default:
         break;
     }
-#ifndef G_OS_WIN32
-    if (set_int_action)
-        sigaction(SIGINT, &previous_int_action, NULL);
-    if (set_abort_action)
-        sigaction(SIGABRT, &previous_abort_action, NULL);
-    if (set_segv_action)
-        sigaction(SIGSEGV, &previous_segv_action, NULL);
-#endif
 
     if (priv->cooldown)
         priv->cooldown();
