@@ -39,7 +39,6 @@ void test_sizegroup (void);
 void test_list_store (void);
 void test_tree_store (void);
 void test_types (void);
-void test_spin_button (void);
 void test_notebook (void);
 void test_construct_only_property (void);
 void test_object_properties (void);
@@ -48,7 +47,6 @@ void test_child_properties (void);
 void test_treeview_column (void);
 void test_icon_view (void);
 void test_combo_box (void);
-void test_combo_box_entry (void);
 void test_cell_view (void);
 void test_dialog (void);
 void test_accelerators (void);
@@ -425,15 +423,7 @@ test_domain (void)
   
   builder = builder_new_from_string (buffer2, -1, NULL);
   domain = gtk_builder_get_translation_domain (builder);
-  cut_assert (domain);
-  cut_assert_equal_string ("domain", domain);
-  g_object_unref (builder);
-  builder = NULL;
-  
-  builder = builder_new_from_string (buffer2, -1, "domain-1");
-  domain = gtk_builder_get_translation_domain (builder);
-  cut_assert (domain);
-  cut_assert_equal_string ("domain-1", domain);
+  cut_assert_equal_string (NULL, domain);
   g_object_unref (builder);
   builder = NULL;
 }
@@ -765,49 +755,6 @@ void test_types (void)
   builder = NULL;
 }
 
-void test_spin_button (void)
-{
-  const gchar buffer[] =
-    "<interface>"
-    "<object class=\"GtkAdjustment\" id=\"adjustment1\">"
-    "<property name=\"lower\">0</property>"
-    "<property name=\"upper\">10</property>"
-    "<property name=\"step-increment\">2</property>"
-    "<property name=\"page-increment\">3</property>"
-    "<property name=\"page-size\">5</property>"
-    "<property name=\"value\">1</property>"
-    "</object>"
-    "<object class=\"GtkSpinButton\" id=\"spinbutton1\">"
-    "<property name=\"visible\">True</property>"
-    "<property name=\"adjustment\">adjustment1</property>"
-    "</object>"
-    "</interface>";
-  GObject *object;
-  GtkAdjustment *adjustment;
-  gdouble value;
-  
-  builder = builder_new_from_string (buffer, -1, NULL);
-  object = gtk_builder_get_object (builder, "spinbutton1");
-  cut_assert (GTK_IS_SPIN_BUTTON (object));
-  adjustment = gtk_spin_button_get_adjustment (GTK_SPIN_BUTTON (object));
-  cut_assert (GTK_IS_ADJUSTMENT (adjustment));
-  g_object_get (adjustment, "value", &value, NULL);
-  cut_assert_equal_int (1, value);
-  g_object_get (adjustment, "lower", &value, NULL);
-  cut_assert_equal_int (0, value);
-  g_object_get (adjustment, "upper", &value, NULL);
-  cut_assert_equal_int (10, value);
-  g_object_get (adjustment, "step-increment", &value, NULL);
-  cut_assert_equal_int (2, value);
-  g_object_get (adjustment, "page-increment", &value, NULL);
-  cut_assert_equal_int (3, value);
-  g_object_get (adjustment, "page-size", &value, NULL);
-  cut_assert_equal_int (5, value);
-  
-  g_object_unref (builder);
-  builder = NULL;
-}
-
 void test_notebook (void)
 {
   const gchar buffer[] =
@@ -976,7 +923,7 @@ void test_children (void)
   button = gtk_builder_get_object (builder, "button1");
   cut_assert (button != NULL);
   cut_assert (GTK_IS_BUTTON (button));
-  cut_assert (strcmp (GTK_WIDGET (GTK_WIDGET (button)->parent)->name, "window1") == 0);
+  cut_assert (strcmp (gtk_buildable_get_name (GTK_BUILDABLE (GTK_WIDGET (button)->parent)), "window1") == 0);
 
   gtk_widget_destroy (GTK_WIDGET (window));
   g_object_unref (builder);
@@ -993,9 +940,9 @@ void test_children (void)
   cut_assert (vbox != NULL);
   cut_assert (GTK_IS_VBOX (vbox));
   cut_assert (GTK_WIDGET (vbox)->parent != NULL);
-  cut_assert (strcmp (GTK_WIDGET (GTK_WIDGET (vbox)->parent)->name, "dialog1") == 0);
+  cut_assert (strcmp (gtk_buildable_get_name (GTK_BUILDABLE (GTK_WIDGET (vbox)->parent)), "dialog1") == 0);
   cut_assert (GTK_CONTAINER (vbox)->border_width == 10);
-  cut_assert (strcmp (GTK_WIDGET (GTK_DIALOG (dialog)->vbox)->name,
+  cut_assert (strcmp (gtk_buildable_get_name (GTK_BUILDABLE (GTK_DIALOG (dialog)->vbox)),
 				"dialog1-vbox") == 0);
 
   action_area = gtk_builder_get_object (builder, "dialog1-action_area");
@@ -1004,8 +951,8 @@ void test_children (void)
   cut_assert (GTK_WIDGET (action_area)->parent != NULL);
   cut_assert (GTK_CONTAINER (action_area)->border_width == 20);
   cut_assert (GTK_DIALOG (dialog)->action_area != NULL);
-  cut_assert (GTK_WIDGET (GTK_DIALOG (dialog)->action_area)->name != NULL);
-  cut_assert (strcmp (GTK_WIDGET (GTK_DIALOG (dialog)->action_area)->name,
+  cut_assert (gtk_buildable_get_name (GTK_BUILDABLE (GTK_DIALOG (dialog)->action_area)) != NULL);
+  cut_assert (strcmp (gtk_buildable_get_name (GTK_BUILDABLE (GTK_DIALOG (dialog)->action_area)),
 				"dialog1-action_area") == 0);
   gtk_widget_destroy (GTK_WIDGET (dialog));
   g_object_unref (builder);
@@ -1122,7 +1069,7 @@ void test_treeview_column (void)
   cut_assert (GTK_IS_TREE_VIEW (treeview));
   column = gtk_tree_view_get_column (GTK_TREE_VIEW (treeview), 0);
   cut_assert (GTK_IS_TREE_VIEW_COLUMN (column));
-  cut_assert_equal_string ("Test", gtk_tree_view_column_get_title (column), "Test");
+  cut_assert_equal_string ("Test", gtk_tree_view_column_get_title (column));
 
   renderers = gtk_tree_view_column_get_cell_renderers (column);
   cut_assert_equal_int (1, g_list_length (renderers));
@@ -1278,76 +1225,6 @@ void test_combo_box (void)
   builder = NULL;
 }
 
-void
-test_combo_box_entry (void)
-{
-  const gchar buffer[] =
-    "<interface>"
-    "  <object class=\"GtkListStore\" id=\"liststore1\">"
-    "    <columns>"
-    "      <column type=\"guint\"/>"
-    "      <column type=\"gchararray\"/>"
-    "    </columns>"
-    "    <data>"
-    "      <row>"
-    "        <col id=\"0\">1</col>"
-    "        <col id=\"1\">Foo</col>"
-    "      </row>"
-    "      <row>"
-    "        <col id=\"0\">2</col>"
-    "        <col id=\"1\">Bar</col>"
-    "      </row>"
-    "    </data>"
-    "  </object>"
-    "  <object class=\"GtkWindow\" id=\"window1\">"
-    "    <child>"
-    "      <object class=\"GtkComboBoxEntry\" id=\"comboboxentry1\">"
-    "        <property name=\"model\">liststore1</property>"
-    "        <property name=\"visible\">True</property>"
-    "        <child>"
-    "          <object class=\"GtkCellRendererText\" id=\"renderer1\"/>"
-    "            <attributes>"
-    "              <attribute name=\"text\">0</attribute>"
-    "            </attributes>"
-    "        </child>"
-    "        <child>"
-    "          <object class=\"GtkCellRendererText\" id=\"renderer2\"/>"
-    "            <attributes>"
-    "              <attribute name=\"text\">1</attribute>"
-    "            </attributes>"
-    "        </child>"
-    "      </object>"
-    "    </child>"
-    "  </object>"
-    "</interface>";
-  GObject *window, *combobox, *renderer;
-  gchar *text;
-
-  builder = builder_new_from_string (buffer, -1, NULL);
-  combobox = gtk_builder_get_object (builder, "comboboxentry1");
-  cut_assert (combobox);
-
-  renderer = gtk_builder_get_object (builder, "renderer2");
-  cut_assert (renderer);
-  g_object_get (renderer, "text", &text, NULL);
-  cut_assert (text);
-  cut_assert_equal_string ("Bar", text);
-  g_free (text);
-
-  renderer = gtk_builder_get_object (builder, "renderer1");
-  cut_assert (renderer);
-  g_object_get (renderer, "text", &text, NULL);
-  cut_assert (text);
-  cut_assert_equal_string ("2", text);
-  g_free (text);
-
-  window = gtk_builder_get_object (builder, "window1");
-  gtk_widget_destroy (GTK_WIDGET (window));
-
-  g_object_unref (builder);
-  builder = NULL;
-}
-
 void
 test_cell_view (void)
 {
@@ -1548,15 +1425,6 @@ test_widget (void)
     "    </child>"
     "  </object>"
    "</interface>";
-  gchar *buffer3 =
-    "<interface>"
-    "  <object class=\"GtkWindow\" id=\"window1\">"
-    "     <accessibility>"
-    "       <atkproperty name=\"AtkObject::accessible_name\" translatable=\"yes\">Contacts</atkproperty>"
-    "       <atkrelation target=\"button1\" type=\"labelled-by\"/>"
-    "     </accessibility>"
-    "  </object>"
-   "</interface>";
   GObject *window1, *button1;
   
   builder = builder_new_from_string (buffer, -1, NULL);
@@ -1579,10 +1447,6 @@ test_widget (void)
   gtk_widget_destroy (GTK_WIDGET (window1));
   g_object_unref (builder);
 
-  builder = builder_new_from_string (buffer3, -1, NULL);
-  window1 = gtk_builder_get_object (builder, "window1");
-  gtk_widget_destroy (GTK_WIDGET (window1));
-  g_object_unref (builder);
   builder = NULL;
 }
 
